# Configuration Files

Windows Git can load a configuration file with the game that sets various attributes of the interpreter window. The configuration file should have the same name as the game except for an extension of .cfg.

The configuration file is a text file where each line contains a key name, followed by an equals sign, then a value, e.g. WindowBorders=no. Possible keys are:

WindowBorders=[yes/no] | Turns on or off borders between windows.
WindowFrame=[yes/no] | Turns on or off the interpreter window's frame, that is, the title bar and the border around the whole window.
WindowMask=[number] | Uses the given Blorb resource number to set the mask for the window from the graphic. If a particular pixel in the graphic is white then the window is transparent at that point, else it is opaque. This key only takes effect if "WindowFrame=no".
WindowWidth=[width] | Sets the width of the interpreter's window so that a single, full-size Glk window will have a width of the given value.
WindowHeight=[height] | Sets the height of the interpreter's window so that a single, full-size Glk window will have a height of the given value.
FullScreen=[yes/no] | If set to "yes", the interpreter's window opens filling the entire screen.
FontName=[font] | Sets the font used for proportional text to the given font name, e.g. Times New Roman.
FontSize=[size] | Sets the size of the font used for proportional text to the given value, measured in points.
FixedFontName=[font] | Sets the font used for fixed width text to the given font name.
FixedFontSize=[size] | Sets the size of the font used for fixed width text to the given value.
FontFile=[filename] | The name of a font file (usually ending in ".ttf") to load fonts from.